@@ -1,14 +1,16 @@
 Base.@kwdef mutable struct Settings
     tidyup_tol::Float64 = 1e-14
     auto_tidyup::Bool = true
+    ProgressMeterKWARGS::NamedTuple = (showspeed = true, printed = true)
 end
 
 function Base.show(io::IO, s::Settings)
-    # To align the output and make it easier to read
-    # we use rpad `11`, which is the length of string: `auto_tidyup`
+    # get maximum field name to align the output and make it easier to read
+    maxLen = maximum(length ∘ String, fieldnames(Settings))
+
     println(io, "QuantumToolbox.jl Settings")
     println(io, "--------------------------")
-    map(n -> println(io, rpad("$n", 11, " "), " = ", getfield(s, n)), fieldnames(Settings))
+    map(n -> println(io, rpad("$n", maxLen, " "), " = ", getfield(s, n)), fieldnames(Settings))
     return nothing
 end
 
@@ -21,6 +23,7 @@ Contains all the default global settings of QuantumToolbox.jl.
 
 - `tidyup_tol::Float64 = 1e-14` : tolerance for [`tidyup`](@ref) and [`tidyup!`](@ref).
 - `auto_tidyup::Bool = true` : Automatically tidyup.
+- `ProgressMeterKWARGS::NamedTuple = (showspeed = true, printed = true)` : Default keyword arguments for progress bar in [`ProgressMeter.jl`](https://github.com/timholy/ProgressMeter.jl). This allows the customization of progress bar.
 
 For detailed explanation of each settings, see our documentation [here](https://qutip.org/QuantumToolbox.jl/stable/users_guide/settings).
 
